package com.mirs.biz.mapper;

import java.util.List;
import com.mirs.biz.domain.Sample;
import com.mirs.biz.dto.IndexSearchDTO;

/**
 * 样片管理Mapper接口
 * 
 * @author kk
 * @date 2025-04-27
 */
public interface SampleMapper 
{
    /**
     * 查询样片管理
     * 
     * @param id 样片管理主键
     * @return 样片管理
     */
    public Sample selectSampleById(Long id);

    /**
     * 查询样片管理列表
     * 
     * @param sample 样片管理
     * @return 样片管理集合
     */
    public List<Sample> selectSampleList(Sample sample);

    /**
     * 新增样片管理
     * 
     * @param sample 样片管理
     * @return 结果
     */
    public int insertSample(Sample sample);

    /**
     * 修改样片管理
     * 
     * @param sample 样片管理
     * @return 结果
     */
    public int updateSample(Sample sample);

    /**
     * 删除样片管理
     * 
     * @param id 样片管理主键
     * @return 结果
     */
    public int deleteSampleById(Long id);

    /**
     * 批量删除样片管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSampleByIds(Long[] ids);

    Sample getOne(Sample sample);

    List getSampleType(String dataType);

    List getSampleModel(IndexSearchDTO dto);
}
